function K=LMIout_cvx(A,B,C,Qx)
%% Stabilizing output-feedback synthesis via LMI
% 
% Given a discrete-time LTI model in the form of 
%
% x(t+1) = A x(t) + B u(t)
% y(t) = C x(t)
%
% the stabilizing control law u(t) = K y(t) is returned as result of a
% Semi-Definite Programming problem involving the state weight matrix Qx.
%
  [n m] = size(B);
  p = size(C,1);

  Qx=eye(n,n);
  
  cvx_begin sdp
    variable Y(m,p)
    variable Q(n,n) symmetric
    variable M(p,p)
    variable g
    minimize g
    subject to 
      [ -Q         Q*A'+C'*Y'*B' (Qx^.5*Q)' ;...
        A*Q+B*Y*C  -Q            zeros(n)   ;...
        Qx^.5*Q    zeros(n)     -g*eye(n)   ] < 0;
      Q>=0
      g>0
      M*C == C*Q
  cvx_end
  
  K=Y*inv(M);
end