function model = identifyQCmodel(maxOrder)

%% Simulation for identification
load MPC_controller;

assignin('base','MPCobj',MPCobj);

Tsim=20;
Ts=0.1;
t=0:Ts:Tsim-Ts;

Ns=length(t);

% initial state
%     theta phi psi  x   y   z   d_th d_ph d_ps  d_x  d_y  d_z
x0 = [0     0   0    0   0   0   0    0    0     0    0    0]';
assignin('base','x0',x0);

% refernce (xyz positions)
clear ref
ref=[ zeros(3,Ns);...
      [ones(1,Ns/2) .5*ones(1,Ns/2)];
      [zeros(1,3*Ns/4) ones(1,Ns/4)];
      [zeros(1,Ns/4) ones(1,3*Ns/4)]; 
      zeros(6,Ns)
    ];


clear pos;
pos{1}=ref(4:6,:);
refs.time=t;
refs.signals.values=ref';
refs.signals.dimensions=12;

assignin('base','refs',refs);

tic
sim('test1',Tsim);
toc

%% Estimation
y = xx.signals.values(1:end-1,4);
u= ref(4,:)';

data = iddata(y,u,Ts);
models=cell(maxOrder,1);
for i=1:maxOrder
  models{i} = pem(data,i);
end

%% Validation
disp('Model validation in progress');
perfInd=[];
for i=1:maxOrder
  [Ae Be Ce De]=ssdata(models{i});
  
  % repeat the model along the three axis as if they were independent
  Ae=blkdiag(Ae,Ae,Ae);
  Be=blkdiag(Be,Be,Be);
  Ce=blkdiag(Ce,Ce,Ce);
  De=blkdiag(De,De,De);
  
  % update enlarged model to the storage variable
  models{i} = ss(Ae,Be,Ce,De,Ts);
  
  assignin('base','Ae',Ae);
  assignin('base','Be',Be);
  assignin('base','Ce',Ce);
  assignin('base','De',De);  

  sim('test2',Tsim);
  pos{2} = xx.signals.values(:,4:6)';
  pos{3} = xx1.signals.values';

  % performance index
  perfInd(i)=sum(sum((pos{2}-pos{3}).^2));
  
  plotTrajectories(pos);
  title(['Simulation with indentified model of order ' num2str(i*3)]);
end


disp(['Performance indices for the ' num2str(i) ' models are:']);
disp(perfInd);
disp('whose sizes are:')
disp(3:3:3*i)
disp('Fit vs complexity index (performance index times dimension)')
disp([3:3:3*i].*perfInd)
[m ind]=min([3:3:3*i].*perfInd);
disp(['which leads to choose model number ' num2str(ind)]);

model=models{ind};
end




